Testing: Short Answer Questions — Runestone Interactive Overview

# Testing: Short Answer Questions

## Short Answer

Q-1: What are the colors in the rainbow?

print("My first program adds a list of numbers") myList = [2, 4, 6, 8, 10] total = 0 for num in myList: total = total + num print(total)

Q-10: What color is a stop sign?

- red

- Red it is.

- brown

- Not brown.

- blue

- Not blue.

- gray

- Not gray.

Before-5-After: Fill in the blanks to make the following sentence: “The red car drove away.”

The car drove .

Q-1: Click the rainbow color(s)This is incorrect

    Red
                Gold
                Blue
                Black

Q-2: Click the rainbow color(s)This is incorrect

Red | Orange | Yellow
White | Green | White
Blue | White | Indigo
White | Violet | White

Q-1: Match the language and the file extension. Review your choice
- C++
- cpp
- Java
- java
- Python
- py

You have attempted of activities on this page

                Q-1: need some text ?
    def fib(num):
    ---
       if num == 0:
           return 0:
    ---
       if num == 1:
           return 1:
    ---
       return fib(num - 1) + fib(num - 2)
    ---
       return fib(num - 1) * fib(num - 2) #paired

On a scale from 1 to 10, how important do you think it is to have a polling directive in the Runestone Tools?

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- 10